@@ -6,8 +6,10 @@ use Carp;
 use Scalar::Util qw(reftype blessed);
 use Tree::XPathEngine;
 use 5.006;
+our $VERSION = '2.02'; # VERSION
+
+# ABSTRACT: an XPath implementation for the PDOM
 
-our $VERSION='2.01';
 
 sub new {
     my ($class,$source) = @_;
@@ -30,34 +32,41 @@ sub new {
     return bless {doc=>$doc},$class;
 }
 
-# PPIx::XPath 1.0.0 allowed the use of partial package names as node names;
-# this collides with the axis specification of proper XPath.
-# Here we change the "old-style" node names into the new names
+
 {
-my $legacy_names_rx;my %new_name_for;
-sub clean_xpath_expr {
-    my (undef,$expr)=@_;
+    my $legacy_names_rx;my %new_name_for;
+    sub clean_xpath_expr {
+        my (undef,$expr)=@_;
 
-    $expr =~ s{$legacy_names_rx}{$new_name_for{$1}}ge;
+        $expr =~ s{$legacy_names_rx}{$new_name_for{$1}}ge;
 
-    return $expr;
-}
+        return $expr;
+    }
 
     my @PPI_Packs;
     # taken from Devel::Symdump
+    # breadth-first search of packages under C<PPI>
     my @packages=('PPI');
     while (my $pack=shift(@packages)) {
-        no strict 'refs';
-        while (my ($key,$val)=each(%{*{"$pack\::"}})) {
+        my %pack_symbols = do {
+            no strict 'refs'; ## no critic(ProhibitNoStrict)
+            %{*{"$pack\::"}}
+        };
+        while (my ($key,$val)=each(%pack_symbols)) {
+            # that {HASH} lookup is special for typeglobs, so we have
+            # to alias a local typeglob to make it work
             local *ENTRY=$val;
+            # does this symbol table entry look like a sub-package?
             if (defined $val && defined *ENTRY{HASH} && $key=~/::$/
                     && $key !~ /^::/
                     && $key ne 'main::' && $key ne '<none>::') {
 
-                my $p = "$pack\::$key";$p =~ s{::$}{}; #}{};
+                # add it to the search list
+                my $p = "$pack\::$key";$p =~ s{::$}{};
                 push @packages,$p;
-                $p =~ s{^PPI::}{};
 
+                # and add it to the map of names
+                $p =~ s{^PPI::}{};
                 next unless $p=~/::/;
 
                 my $newname=$p;
@@ -67,12 +76,17 @@ sub clean_xpath_expr {
             }
         }
     }
-    $legacy_names_rx='\b('.join('|',
-                            sort {length($b) <=> length($a)} @PPI_Packs
+
+    # @PPI_Packs now contains all the old-style names, build a regex
+    # to match them (the sort is important, we want to match longer
+    # names first!)
+    $legacy_names_rx='\b('.join(q{|},
+                                sort {length($b) <=> length($a)} @PPI_Packs
                             ).')\b';
     $legacy_names_rx=qr{$legacy_names_rx};
 }
 
+
 sub match {
     my ($self,$expr) = @_;
 
@@ -81,7 +95,8 @@ sub match {
     Tree::XPathEngine->new()->findnodes($expr,$self->{doc});
 }
 
-package PPI::Element;
+
+package PPI::Element; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
@@ -174,13 +189,13 @@ sub _xpath_ancestors {
     return @ancestors;
 }
 
-package PPI::Token;
+package PPI::Token; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
 sub xpath_get_child_nodes       { return }
 
-package PPI::Token::Quote::Double;
+package PPI::Token::Quote::Double; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
@@ -189,7 +204,7 @@ sub xpath_get_attributes        {
         PPIx::XPath::Attr->new($_[0],'interpolations'),
 }
 
-package PPI::Token::Number;
+package PPI::Token::Number; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
@@ -198,7 +213,7 @@ sub xpath_get_attributes        {
         PPIx::XPath::Attr->new($_[0],'base'),
 }
 
-package PPI::Token::Word;
+package PPI::Token::Word; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
@@ -207,7 +222,7 @@ sub xpath_get_attributes        {
         PPIx::XPath::Attr->new($_[0],'method-call'),
 }
 
-package PPI::Token::Comment;
+package PPI::Token::Comment; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
@@ -216,7 +231,7 @@ sub xpath_get_attributes        {
         PPIx::XPath::Attr->new($_[0],'line'),
 }
 
-package PPI::Token::HereDoc;
+package PPI::Token::HereDoc; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
@@ -227,7 +242,7 @@ sub xpath_get_attributes        {
         PPIx::XPath::Attr->new($_[0],'terminator'),
 }
 
-package PPI::Token::Prototype;
+package PPI::Token::Prototype; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
@@ -235,7 +250,7 @@ sub xpath_to_literal            { $_[0]->prototype }
 sub xpath_get_value             { $_[0]->prototype }
 sub xpath_string_value          { $_[0]->prototype }
 
-package PPI::Node;
+package PPI::Node; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
@@ -245,7 +260,7 @@ sub xpath_get_attributes        {
         PPIx::XPath::Attr->new($_[0],'scope'),
 }
 
-package PPI::Token::Attribute;
+package PPI::Token::Attribute; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
@@ -255,7 +270,7 @@ sub xpath_get_attributes        {
         PPIx::XPath::Attr->new($_[0],'parameters'),
 }
 
-package PPI::Token::Symbol;
+package PPI::Token::Symbol; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
@@ -267,7 +282,7 @@ sub xpath_get_attributes        {
         PPIx::XPath::Attr->new($_[0],'symbol_typel'),
 }
 
-package PPI::Statement;
+package PPI::Statement; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
@@ -278,7 +293,7 @@ sub xpath_get_attributes        {
         PPIx::XPath::Attr->new($_[0],'type'),
 }
 
-package PPI::Statement::Sub;
+package PPI::Statement::Sub; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
@@ -290,7 +305,7 @@ sub xpath_get_attributes        {
         PPIx::XPath::Attr->new($_[0],'reserved'),
 }
 
-package PPI::Statement::Package;
+package PPI::Statement::Package; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
@@ -300,7 +315,7 @@ sub xpath_get_attributes        {
         PPIx::XPath::Attr->new($_[0],'file-scoped'),
 }
 
-package PPI::Statement::Include;
+package PPI::Statement::Include; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
@@ -313,7 +328,7 @@ sub xpath_get_attributes        {
         PPIx::XPath::Attr->new($_[0],'pragma'),
 }
 
-package PPI::Structure;
+package PPI::Structure; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
@@ -324,7 +339,7 @@ sub xpath_get_attributes        {
         PPIx::XPath::Attr->new($_[0],'braces'),
 }
 
-package PPI::Document;
+package PPI::Document; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
@@ -333,7 +348,7 @@ sub xpath_get_parent_node       { return }
 sub xpath_is_attribute_node     { 0 }
 sub xpath_is_document_node      { 1 }
 
-package PPIx::XPath::Attr;
+package PPIx::XPath::Attr; ## no critic(ProhibitMultiplePackages)
 use strict;
 use warnings;
 
@@ -362,7 +377,7 @@ sub xpath_get_value             { $_[0]->{value} }
 sub xpath_string_value          { $_[0]->{value} }
 sub xpath_to_number             { Tree::XPathEngine::Number->new($_[0]->{value}) }
 
-sub xpath_cmp($$) {
+sub xpath_cmp {
     my( $a, $b)= @_;
     if ( UNIVERSAL::isa( $b, 'PPIx::XPath::Attr')) {
         # 2 attributes, compare their elements, then their name
@@ -381,16 +396,25 @@ sub xpath_cmp($$) {
 }
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 PPIx::XPath - an XPath implementation for the PDOM
 
+=head1 VERSION
+
+version 2.02
+
 =head1 SYNOPSIS
 
   use PPI;
-  use PPI::XPath;
+  use PPIx::XPath;
   use Tree::XPathEngine;
 
   my $pdom = PPI::Document->new('some_code.pl');
@@ -426,6 +450,7 @@ Each node in the PDOM is an element as seen by XPath
 =item *
 
 The name of the element is the class name of the node, minus the
+
 initial C<PPI::>, with C<::> replaced by C<->. That is:
 
   ($xpath_name = substr($pdom_node->class,5)) =~ s/::/-/g;
@@ -444,6 +469,47 @@ all scalar-valued accessors of PDOM nodes are visible as attributes
 
 =back
 
+=head1 METHODS
+
+=head2 C<new>
+
+  my $pxp  = PPIx::XPath->new("some_code.pl");
+
+  my $pxp  = PPIx::XPath->new($pdom);
+
+Only useful for the backward-compatible, and deprecated, interface.
+Returns an instance of C<PPIx::XPath> tied to the given document.
+
+=head2 C<clean_xpath_expr>
+
+  my $new_xpath_expr = $pxp->clean_xpath_expr($old_xpath_expr);
+
+C<PPIx::XPath> version 1.0.0 allowed the use of partial package names
+(like C<Token::Number>) as element names: this collides with the axis
+specification of proper XPath. For this reason, in newer version of
+C<PPIx::XPath>, the element name is the class name of the PDOM node,
+minus the initial C<PPI::>, with C<::> replaced by C<-> (like
+C<Token-Number>).
+
+This method replaces all occurrences of PPI package names in the given
+string with the new names.
+
+=head2 C<match>
+
+  my @subs = $pxp->match("//Statement::Sub");
+  my $vars = $pxp->match("//Token::Symbol");
+
+Only useful for the backward-compatible, and deprecated,
+interface. From the document this instance was built against, returns
+the nodes that match the given XPath expression.
+
+You should not use this method, you should call L<<
+C<findnodes>|Tree::XPathEngine/findnodes >> instead:
+
+  my $xpath = Tree::XPathEngine->new();
+  my @subs = $xpath->findnodes('//Statement-Sub',$pdom);
+  my @vars = $xpath->findnodes('//Token-Symbol',$pdom);
+
 =head1 BUGS and LIMITATIONS
 
 =over 4
@@ -455,6 +521,7 @@ all scalar-valued accessors of PDOM nodes are visible as attributes
 =item *
 
 node ordering is slow, because I could not find a way in PPI to
+
 compare two nodes for document order; suggestions are most welcome
 
 =back
@@ -467,10 +534,17 @@ L<Tree::XPathEngine>
 
 L<http://www.w3.org/TR/xpath> (the XPath specification)
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Dan Brook <cpan@broquaint.com> original author
 
 Gianni Ceccarelli <dakkar@thenautilus.net> Tree::XPathEngine-based re-implementation
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by Gianni Ceccarelli <dakkar@thenautilus.net>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
